@@ -4,7 +4,7 @@ import logging
 class DefaultConfig:
     ENV = "prod"
     LOG_LEVEL = logging.INFO
-    BASE = "https://www.staffjoy.com/api/v2/"
+    BASE = "https://suite.staffjoy.com/api/v2/"
     REQUEST_SLEEP = 0.5
 
 
@@ -16,7 +16,7 @@ class StageConfig(DefaultConfig):
 class DevelopmentConfig(DefaultConfig):
     ENV = "dev"
     LOG_LEVEL = logging.DEBUG
-    BASE = "http://dev.staffjoy.com/api/v2/"
+    BASE = "http://suite.local/api/v2/"
 
 
 config_from_env = {  # Determined in main.py
