@@ -1,15 +1,15 @@
-from ..resource import Resource
-from .location import Location
-from .admin import Admin
-from .organization_worker import OrganizationWorker
+from staffjoy.resource import Resource
+from staffjoy.resources.location import Location
+from staffjoy.resources.admin import Admin
+from staffjoy.resources.organization_worker import OrganizationWorker
 
 
 class Organization(Resource):
     PATH = "organizations/{organization_id}"
     ID_NAME = "organization_id"
 
-    def get_locations(self):
-        return Location.get_all(parent=self)
+    def get_locations(self, **kwargs):
+        return Location.get_all(parent=self, **kwargs)
 
     def get_location(self, id):
         return Location.get(parent=self, id=id)
