@@ -1,8 +1,9 @@
-from ..resource import Resource
-from .worker import Worker
-from .schedule import Schedule
-from .shift import Shift
-from .recurring_shift import RecurringShift
+from staffjoy.resource import Resource
+from staffjoy.resources.worker import Worker
+from staffjoy.resources.schedule import Schedule
+from staffjoy.resources.shift import Shift
+from staffjoy.resources.shift_query import ShiftQuery
+from staffjoy.resources.recurring_shift import RecurringShift
 
 
 class Role(Resource):
@@ -19,7 +20,7 @@ class Role(Resource):
         return Worker.create(parent=self, **kwargs)
 
     def get_schedules(self, **kwargs):
-        return Schedule.get_all(parent=self)
+        return Schedule.get_all(parent=self, **kwargs)
 
     def get_schedule(self, id):
         return Schedule.get(parent=self, id=id)
@@ -33,6 +34,9 @@ class Role(Resource):
     def create_shift(self, **kwargs):
         return Shift.create(parent=self, **kwargs)
 
+    def get_shift_query(self, **kwargs):
+        return ShiftQuery.get_all(parent=self, **kwargs)
+
     def get_recurring_shifts(self, **kwargs):
         return RecurringShift.get_all(parent=self, **kwargs)
 
