@@ -1,6 +1,6 @@
-from ..resource import Resource
-from .session import Session
-from .apikey import ApiKey
+from staffjoy.resource import Resource
+from staffjoy.resources.session import Session
+from staffjoy.resources.apikey import ApiKey
 
 
 class User(Resource):
@@ -11,7 +11,7 @@ class User(Resource):
         return Session.get_all(parent=self)
 
     def get_session(self, id):
-        return Session.get(parset=self, id=id)
+        return Session.get(parent=self, id=id)
 
     def get_apikeys(self):
         return ApiKey.get_all(parent=self)
